@@ -25,7 +25,14 @@ Implementation Notes
 import time
 from adafruit_hid.keycode import Keycode
 
-__version__ = "1.0.0"
+try:
+    from typing import Optional
+    from adafruit_hid.keyboard import Keyboard
+    from adafruit_hid.keyboard_layout_base import KeyboardLayoutBase
+except ImportError:
+    pass
+
+__version__ = "1.0.1"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Ducky.git"
 
 commands = {
@@ -114,7 +121,9 @@ class Ducky:
 
     """
 
-    def __init__(self, filename, keyboard, layout):
+    def __init__(
+        self, filename: str, keyboard: Keyboard, layout: KeyboardLayoutBase
+    ) -> None:
         self.keyboard = keyboard
         self.layout = layout
         self.lines = []
@@ -125,9 +134,9 @@ class Ducky:
             for line in duckyscript:
                 self.lines.append(line[:-1])
 
-    def loop(
-        self, line=None
-    ):  # pylint: disable=too-many-branches,too-many-return-statements
+    def loop(  # pylint: disable=too-many-return-statements
+        self, line: Optional[str] = None
+    ) -> bool:  # pylint: disable=too-many-branches
         """ Function that sends a line of the DuckyScript file over hid every time it is called """
         if line is None:
             try:
@@ -193,7 +202,7 @@ class Ducky:
         self.lines.pop(0)
         return True
 
-    def write_key(self, start):
+    def write_key(self, start: str) -> None:
         """ Writes the keys over HID. Used to help with more complicated commands """
         if start in commands:
             self.keyboard.press(commands[start])
